/// The different available logging levels.
// These only need to be represented as an unsigned
// integer as there won't be that many of these.
#[repr(u8)]
#[derive(Clone, Copy, PartialEq, PartialOrd, Eq, Ord)]
pub enum Levels
{
   /// Designates a serious, program
   /// stopping, error.
   Error,

   /// Designates a problem, but it is not
   /// something that will stop the program
   /// from running.
   Warn,

   /// Designates useful information.
   Info,

   /// Designates debugging only information.
   Debug
}



impl Levels
{
   /// Get a str representation of this variant.
   pub fn to_str(&self) -> &'static str
   {
      match *self
      {
         Levels::Error => "Error",
         Levels::Warn => "Warn",
         Levels::Info => "Info",
         Levels::Debug => "Debug"
      }
   }

   /// Get the byte(u8) value of this variant.
   pub fn get_val(&self) -> u8
   {
      match *self
      {
         Levels::Error => 0,
         Levels::Warn => 1,
         Levels::Info => 2,
         Levels::Debug => 3
      }
   }
}

impl ::std::convert::From<u8> for Levels
{
   fn from(lvl: u8) -> Levels
   {
      match lvl
      {
         0 => Levels::Error,
         1 => Levels::Warn,
         2 => Levels::Info,
         3 => Levels::Debug,
         _ => Levels::Debug
      }
   }
}

impl ::std::convert::From<Levels> for u8
{
   fn from(lvl: Levels) -> u8
   {
      lvl.get_val()
   }
}

impl ::std::fmt::Debug for Levels
{
   fn fmt(&self, f: &mut ::std::fmt::Formatter) -> ::std::fmt::Result
   {
      write!(f, "{}", self.to_str())
   }
}

impl ::std::fmt::Display for Levels
{
   fn fmt(&self, f: &mut ::std::fmt::Formatter) -> ::std::fmt::Result
   {
      write!(f, "{}", self.to_str())
   }
}
